==> SDL2-2.0.20.tar.lz: SDL2-2.0.20/src/video/emscripten/SDL_emscriptenvideo.h <==
/*
  Simple DirectMedia Layer
  Copyright (C) 1997-2022 Sam Lantinga <slouken@libsdl.org>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/
#include "../../SDL_internal.h"

#ifndef SDL_emscriptenvideo_h_
#define SDL_emscriptenvideo_h_

#include "../SDL_sysvideo.h"
#include "../../events/SDL_touch_c.h"
#include <emscripten/emscripten.h>
#include <emscripten/html5.h>

#if SDL_VIDEO_OPENGL_EGL
#include <EGL/egl.h>
#endif

typedef struct SDL_WindowData
{
#if SDL_VIDEO_OPENGL_EGL
    EGLSurface egl_surface;
#endif
    SDL_Window *window;
    SDL_Surface *surface;

    char *canvas_id;

    float pixel_ratio;

    SDL_bool external_size;

    int requested_fullscreen_mode;
    SDL_bool fullscreen_resize;

    SDL_bool has_pointer_lock;
} SDL_WindowData;

#endif /* SDL_emscriptenvideo_h_ */

/* vi: set ts=4 sw=4 expandtab: */

==> SDL3-3.4.2.tar.lz: SDL3-3.4.2/src/video/emscripten/SDL_emscriptenvideo.h <==
/*
  Simple DirectMedia Layer
  Copyright (C) 1997-2026 Sam Lantinga <slouken@libsdl.org>

  This software is provided 'as-is', without any express or implied
  warranty.  In no event will the authors be held liable for any damages
  arising from the use of this software.

  Permission is granted to anyone to use this software for any purpose,
  including commercial applications, and to alter it and redistribute it
  freely, subject to the following restrictions:

  1. The origin of this software must not be misrepresented; you must not
     claim that you wrote the original software. If you use this software
     in a product, an acknowledgment in the product documentation would be
     appreciated but is not required.
  2. Altered source versions must be plainly marked as such, and must not be
     misrepresented as being the original software.
  3. This notice may not be removed or altered from any source distribution.
*/
#include "SDL_internal.h"

#ifndef SDL_emscriptenvideo_h_
#define SDL_emscriptenvideo_h_

#include "../SDL_sysvideo.h"
#include "../../events/SDL_touch_c.h"
#include <emscripten/emscripten.h>
#include <emscripten/html5.h>

struct SDL_WindowData
{
    SDL_Window *window;
    SDL_Surface *surface;

    SDL_GLContext gl_context;

    int non_fill_document_width;
    int non_fill_document_height;

    char *canvas_id;
    char *keyboard_element;

    float pixel_ratio;

    bool external_size;

    Uint32 fullscreen_mode_flags;
    bool fullscreen_resize;
    bool fullscreen_change_in_progress;

    bool has_pointer_lock;

    bool mouse_focus_loss_pending;
};

extern SDL_Window *Emscripten_fill_document_window;

bool Emscripten_ShouldSetSwapInterval(int interval);

#endif // SDL_emscriptenvideo_h_
